@@ -544,7 +544,7 @@ sub _attributes
     {
 	next unless (defined $string);
 	next if ($string =~ /^\s*$/);
-	my ($attr, $expr) = $string =~ /^\s*((?:\w|\:)+)\s+(.*?)\s*$/;
+	my ($attr, $expr) = $string =~ /^\s*([A-Za-z_:][A-Za-z0-9_:.-]*)\s+(.*?)\s*$/;
         if (not defined $attr or not defined $expr)
         {
             warn "Attributes expression '$string' does not seem valid - Skipped";
